summaryrefslogtreecommitdiffstats
path: root/src/imports/multimedia/qdeclarativeradiodata.cpp
diff options
context:
space:
mode:
authorAngus Cummings <angus.cummings@nokia.com>2012-04-30 16:49:23 +1000
committerQt by Nokia <qt-info@nokia.com>2012-05-16 05:21:25 +0200
commit9e6d03584a097964e5f08c46cd02338b0b043080 (patch)
treed00b2c09412236e387337890bb2260dc2d3741d6 /src/imports/multimedia/qdeclarativeradiodata.cpp
parentfdb5c419c4fb7b1ae0268e496ccdd0ffa03b74ce (diff)
Minor doc fixes for QML
renaming QML element to QML type removing some \fn tags that were making the docs not build some rewording some new signal docs Change-Id: I9b350dad1780276959aef4105e53b91082a6083e Reviewed-by: Dmytro Poplavskiy <dmytro.poplavskiy@nokia.com>
Diffstat (limited to 'src/imports/multimedia/qdeclarativeradiodata.cpp')
-rw-r--r--src/imports/multimedia/qdeclarativeradiodata.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/imports/multimedia/qdeclarativeradiodata.cpp b/src/imports/multimedia/qdeclarativeradiodata.cpp
index 7936dd6f4..cd69913d9 100644
--- a/src/imports/multimedia/qdeclarativeradiodata.cpp
+++ b/src/imports/multimedia/qdeclarativeradiodata.cpp
@@ -46,16 +46,16 @@ QT_BEGIN_NAMESPACE
/*!
\qmlclass RadioData QDeclarativeRadioData
\inqmlmodule QtMultimedia 5
- \brief The RadioData element allows you to access RDS data from a QML application.
+ \brief The RadioData type allows you to access RDS data from a QML application.
\ingroup multimedia_qml
\ingroup multimedia_radio_qml
\inherits Item
- This element is part of the \b{QtMultimedia 5.0} module.
+ This type is part of the \b{QtMultimedia 5.0} module.
- The \c RadioData element is your gateway to all the data available through RDS. RDS is the Radio Data System
+ \c RadioData is your gateway to all the data available through RDS. RDS is the Radio Data System
which allows radio stations to broadcast information like the \l stationId, \l programType, \l programTypeName,
- \l stationName, and \l radioText. This information can be read from the \c RadioData element. It also allows
+ \l stationName, and \l radioText. This information can be read from the \c RadioData. It also allows
you to set whether the radio should tune to alternative frequencies if the current signal strength falls too much.
\qml
@@ -88,11 +88,11 @@ QT_BEGIN_NAMESPACE
\endqml
- You use \c RadioData together with the \l Radio element, either by
- accessing the \c radioData property of the Radio element, or
- creating a separate RadioData element. The properties of the
- RadioData element will reflect the information broadcast by the
- radio station the Radio element is currently tuned to.
+ You use \c RadioData together with a \l Radio, either by
+ accessing the \c radioData property of the Radio, or
+ creating a separate RadioData. The properties of the
+ RadioData type will reflect the information broadcast by the
+ radio station the Radio is currently tuned to.
\sa {Radio Overview}
*/
@@ -299,7 +299,7 @@ void QDeclarativeRadioData::connectSignals()
SIGNAL(alternativeFrequenciesEnabledChanged(bool)));
// Note we map availabilityError->availability
// Since the radio data element depends on the service for the tuner, the availability is also dictated from the tuner
connect(m_radioTuner, SIGNAL(availabilityErrorChanged(QtMultimedia::AvailabilityError)), this, SLOT(_q_availabilityChanged(QtMultimedia::AvailabilityError)));
connect(m_radioData, SIGNAL(error(QRadioData::Error)), this, SLOT(_q_error(QRadioData::Error)));
@@ -299,7 +299,7 @@ void QDeclarativeRadioData::connectSignals()
SIGNAL(alternativeFrequenciesEnabledChanged(bool)));
// Note we map availabilityError->availability
- // Since the radio data element depends on the service for the tuner, the availability is also dictated from the tuner
+ // Since the radio data type depends on the service for the tuner, the availability is also dictated from the tuner
connect(m_radioTuner, SIGNAL(availabilityErrorChanged(QtMultimedia::AvailabilityError)), this, SLOT(_q_availabilityChanged(QtMultimedia::AvailabilityError)));
connect(m_radioData, SIGNAL(error(QRadioData::Error)), this, SLOT(_q_error(QRadioData::Error)));